# Contributing to OpenfoodLib


Clone the repo and install packages running (on ubuntu for other os, check the command to execute)

`python -m pip install -r requirements.txt`

Install pre commit hook

`pre-commit install`

Create a feature branch 

`git checkout -b feature/name_of_feature`

Once your development is finished, do a merge request
